#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_EIGHT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_EIGHT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/eight.hpp>

#endif
